install.packages("survey", lib="X")
library(survey, lib.loc = "X")

#load CHPS W1 data (.csv).
chps_data <- read.table("X.csv",
                   header = TRUE,
                   sep = ";")


#function to build the cross-classification variable of gender, age, and education.
edit_MS <- function(MS) {
  
  MS$educR <- as.character(MS$educ) 
  MS$educR[MS$educR %in% c("0","1","2")] <- "1"
  MS$educR[MS$educR %in% c("3","4","5","6","7")] <- "2"
  MS$educR[MS$educR %in% c("8","9","10","11")] <- "3"
  MS$educR[MS$educR %in% c("88","99")] <- "0"  
  MS$educR <- as.factor(MS$educR) 
  
  MS$ageR1 <- as.character(MS$age) 
  MS$ageR1[MS$age<=150] <- "4"
  MS$ageR1[MS$age<=54] <- "3"
  MS$ageR1[MS$age<=34] <- "2"
  MS$ageR1[MS$age<=17] <- "1"
  MS$ageR1[MS$age==999998] <- "0"
  
  MS$ageR2 <- as.character(MS$age) 
  MS$ageR2[MS$age<=150] <- "3"
  MS$ageR2[MS$age<=54] <- "2"
  MS$ageR2[MS$age<=34] <- "1"
  MS$ageR2[MS$age<=9] <- "4"
  MS$ageR2[MS$age==999998] <- "0"
  
  MS$ageR3 <- as.character(MS$age) 
  MS$ageR3[MS$age<=150] <- "3"
  MS$ageR3[MS$age<=54] <- "2"
  MS$ageR3[MS$age<=34] <- "1"
  MS$ageR3[MS$age<=14] <- "4"
  MS$ageR3[MS$age==999998] <- "0"
  
    
  MS$demogr1  <-
    with(MS, interaction(sex, ageR1, educR, drop = TRUE, sep = ""))
  MS
  
  MS$demogr2  <-
    with(MS, interaction(sex, ageR2, educR, drop = TRUE, sep = ""))
  MS
  
  MS$demogr3  <-
    with(MS, interaction(sex, ageR3, educR, drop = TRUE, sep = ""))
  MS}

chps_demogr <- edit_MS(chps_data)

table(chps_demogr$region)
table(chps_demogr$demogr1)
table(chps_demogr$demogr2)
table(chps_demogr$demogr3)

chps_pid <- c("pid")
chps_pid <- chps_demogr[chps_pid]

#subset data. 
hh_hh <- subset(chps_demogr, hh_hh==1, 
                  select=c(pid, region))
hh_indi <- subset(chps_demogr, hh_indi==1, 
                select=c(pid, demogr1, region))
indi <- subset(chps_demogr, indi==1, 
                  select=c(pid, demogr1, region))
indi_proxy <- subset(chps_demogr, indi_proxy==1, 
               select=c(pid, demogr1, region))
papi_adult <- subset(chps_demogr, papi_adult==1, 
                     select=c(pid, demogr1, region))
papi_child <- subset(chps_demogr, papi_child==1, 
                     select=c(pid, sex, region))
adult_child <- subset(chps_demogr, adult_child==1, 
                      select=c(pid, demogr2, region))
adult_child15 <- subset(chps_demogr, adult_child15==1, 
                      select=c(pid, demogr3, region))
indi_child15 <- subset(chps_demogr, indi_child15==1, 
                        select=c(pid, demogr3, region))
diary_adult <- subset(chps_demogr, diary_adult==1, 
                       select=c(pid, demogr1, region))
diary_adult_D <- subset(chps_demogr, diary_adult==1, 
                      select=c(pid, demogr1, region, day))
diary_child <- subset(chps_demogr, diary_child==1, 
                      select=c(pid, sex, region))
diary_child_D <- subset(chps_demogr, diary_child==1, 
                      select=c(pid, sex, region, day))
indi_papi <- subset(chps_demogr, indi_papi==1, 
                      select=c(pid, demogr1, region))
indi_diary <- subset(chps_demogr, indi_diary==1, 
                     select=c(pid, demogr1, region))
indi_diary_D <- subset(chps_demogr, indi_diary==1, 
                    select=c(pid, demogr1, region, day))
adult_papi_diary <- subset(chps_demogr, adult_papi_diary==1, 
                           select=c(pid, demogr1, region))
adult_papi_diary_D <- subset(chps_demogr, adult_papi_diary==1, 
                     select=c(pid, demogr1, region, day))
indi_papi_diary <- subset(chps_demogr, indi_papi_diary==1, 
                           select=c(pid, demogr1, region))
indi_papi_diary_D <- subset(chps_demogr, indi_papi_diary==1, 
                          select=c(pid, demogr1, region, day))
child_papi_diary <- subset(chps_demogr, child_papi_diary==1, 
                          select=c(pid, sex, region))
child_papi_diary_D <- subset(chps_demogr, child_papi_diary==1, 
                           select=c(pid, sex, region, day))

#create survey objects.
hh_hh.unweighted <- svydesign(ids=~1, data=hh_hh)
hh_indi.unweighted <- svydesign(ids=~1, data=hh_indi)
indi.unweighted <- svydesign(ids=~1, data=indi)
indi_proxy.unweighted <- svydesign(ids=~1, data=indi_proxy)
papi_adult.unweighted <- svydesign(ids=~1, data=papi_adult)
papi_child.unweighted <- svydesign(ids=~1, data=papi_child)
adult_child.unweighted <- svydesign(ids=~1, data=adult_child)
adult_child15.unweighted <- svydesign(ids=~1, data=adult_child15)
indi_child15.unweighted <- svydesign(ids=~1, data=indi_child15)
diary_adult.unweighted <- svydesign(ids=~1, data=diary_adult)
diary_adult_D.unweighted <- svydesign(ids=~1, data=diary_adult_D)
diary_child.unweighted <- svydesign(ids=~1, data=diary_child)
diary_child_D.unweighted <- svydesign(ids=~1, data=diary_child_D)
indi_papi.unweighted <- svydesign(ids=~1, data=indi_papi)
indi_diary.unweighted <- svydesign(ids=~1, data=indi_diary)
indi_diary_D.unweighted <- svydesign(ids=~1, data=indi_diary_D)
adult_papi_diary.unweighted <- svydesign(ids=~1, data=adult_papi_diary)
adult_papi_diary_D.unweighted <- svydesign(ids=~1, data=adult_papi_diary_D)
indi_papi_diary.unweighted <- svydesign(ids=~1, data=indi_papi_diary)
indi_papi_diary_D.unweighted <- svydesign(ids=~1, data=indi_papi_diary_D)
child_papi_diary.unweighted <- svydesign(ids=~1, data=child_papi_diary)
child_papi_diary_D.unweighted <- svydesign(ids=~1, data=child_papi_diary_D)


#define population distributions for the weighting variables.
hh_hh_region.dist <- data.frame(region = c("10","20","31","32","41", 
                                           "42","51","52","53","63", 
                                           "64","71","72","80"),
                                  Freq = nrow(hh_hh) * c(0.132456, 0.11955 , 0.060042, 0.055403, 0.029463, 
                                                         0.080534, 0.041896, 0.052171, 0.047403, 0.045371, 
                                                         0.10823 , 0.058962, 0.052497, 0.116021))

hh_indi_region.dist <- data.frame(region = c("10","20","31","32","41", 
                                             "42","51","52","53","63", 
                                             "64","71","72","80"),
                                 Freq = nrow(hh_indi) * c(0.119749, 0.125271, 0.060447, 0.054602, 0.028313, 
                                                          0.078098, 0.041654, 0.052288, 0.048966, 0.048327, 
                                                          0.111313, 0.060239, 0.055471, 0.115263))

indi_region.dist <- data.frame(region = c("10", "20", "31", "32", "41",
                                          "42", "51", "52", "53", "63",
                                          "64", "71", "72", "80"),
                                  Freq = nrow(indi) * c(0.121456, 0.122799, 0.060377, 0.054902, 0.028408, 
                                                        0.077461, 0.041344, 0.052328, 0.048833, 0.048369, 
                                                        0.11169 , 0.060394, 0.055884, 0.115754))

indi_proxy_region.dist <- data.frame(region = c("10", "20", "31", "32", "41",
                                                "42", "51", "52", "53", "63",
                                                "64", "71", "72", "80"),
                               Freq = nrow(indi_proxy) * c(0.121456, 0.122799, 0.060377, 0.054902, 0.028408, 
                                                     0.077461, 0.041344, 0.052328, 0.048833, 0.048369, 
                                                     0.11169 , 0.060394, 0.055884, 0.115754))

papi_adult_region.dist <- data.frame(region = c("10", "20", "31", "32", "41",
                                                "42", "51", "52", "53", "63",
                                                "64", "71", "72", "80"),
                                     Freq = nrow(papi_adult) * c(0.121456, 0.122799, 0.060377, 0.054902, 0.028408, 
                                                                 0.077461, 0.041344, 0.052328, 0.048833, 0.048369, 
                                                                 0.11169 , 0.060394, 0.055884, 0.115754))

papi_child_region.dist <- data.frame(region = c("10", "20", "31", "32", "41",
                                                "42", "51", "52", "53", "63",
                                                "64", "71", "72", "80"),
                                     Freq = nrow(papi_child) * c(0.096628, 0.13038 , 0.062331, 0.053434, 0.029065, 
                                                                 0.084549, 0.04399 , 0.053803, 0.051264, 0.050891, 
                                                                 0.107378, 0.061138, 0.056397, 0.118753))

adult_child_region.dist <- data.frame(region = c("10", "20", "31", "32", "41",
                                                 "42", "51", "52", "53", "63",
                                                 "64", "71", "72", "80"),
                                      Freq = nrow(adult_child) * c(0.119484, 0.123401, 0.060532, 0.054785, 0.02846 , 
                                                                   0.078024, 0.041554, 0.052445, 0.049026, 0.048569, 
                                                                   0.111348, 0.060453, 0.055925, 0.115992))

adult_child15_region.dist <- data.frame(region = c("10", "20", "31", "32", "41",
                                                   "42", "51", "52", "53", "63",
                                                   "64", "71", "72", "80"),
                                        Freq = nrow(adult_child15) * c(0.120587, 0.12286 , 0.060451, 0.054849, 0.028448, 
                                                                       0.077657, 0.041442, 0.052409, 0.04896 , 0.048495, 
                                                                       0.111548, 0.060433, 0.055935, 0.115927))

indi_child15_region.dist <- data.frame(region = c("10", "20", "31", "32", "41",
                                                  "42", "51", "52", "53", "63",
                                                  "64", "71", "72", "80"),
                                       Freq = nrow(indi_child15) * c(0.120587, 0.12286 , 0.060451, 0.054849, 0.028448, 
                                                                     0.077657, 0.041442, 0.052409, 0.04896 , 0.048495, 
                                                                     0.111548, 0.060433, 0.055935, 0.115927))

diary_adult_region.dist <- data.frame(region = c("10", "20", "31", "32", "41",
                                                 "42", "51", "52", "53", "63",
                                                 "64", "71", "72", "80"),
                                     Freq = nrow(diary_adult) * c(0.121456, 0.122799, 0.060377, 0.054902, 0.028408, 
                                                                 0.077461, 0.041344, 0.052328, 0.048833, 0.048369, 
                                                                 0.11169 , 0.060394, 0.055884, 0.115754))

diary_child_region.dist <- data.frame(region = c("10", "20", "31", "32", "41",
                                                "42", "51", "52", "53", "63",
                                                "64", "71", "72", "80"),
                                     Freq = nrow(diary_child) * c(0.096628, 0.13038 , 0.062331, 0.053434, 0.029065, 
                                                                  0.084549, 0.04399 , 0.053803, 0.051264, 0.050891, 
                                                                  0.107378, 0.061138, 0.056397, 0.118753))

indi_papi_region.dist <- data.frame(region = c("10", "20", "31", "32", "41",
                                               "42", "51", "52", "53", "63",
                                               "64", "71", "72", "80"),
                                      Freq = nrow(indi_papi) * c(0.121456, 0.122799, 0.060377, 0.054902, 0.028408, 
                                                                   0.077461, 0.041344, 0.052328, 0.048833, 0.048369, 
                                                                   0.11169 , 0.060394, 0.055884, 0.115754))

indi_diary_region.dist <- data.frame(region = c("10", "20", "31", "32", "41",
                                               "42", "51", "52", "53", "63",
                                               "64", "71", "72", "80"),
                                    Freq = nrow(indi_diary) * c(0.121456, 0.122799, 0.060377, 0.054902, 0.028408, 
                                                               0.077461, 0.041344, 0.052328, 0.048833, 0.048369, 
                                                               0.11169 , 0.060394, 0.055884, 0.115754))

adult_papi_diary_region.dist <- data.frame(region = c("10", "20", "31", "32", "41",
                                                "42", "51", "52", "53", "63",
                                                "64", "71", "72", "80"),
                                     Freq = nrow(adult_papi_diary) * c(0.121456, 0.122799, 0.060377, 0.054902, 0.028408, 
                                                                 0.077461, 0.041344, 0.052328, 0.048833, 0.048369, 
                                                                 0.11169 , 0.060394, 0.055884, 0.115754))

indi_papi_diary_region.dist <- data.frame(region = c("10", "20", "31", "32", "41",
                                                      "42", "51", "52", "53", "63",
                                                      "64", "71", "72", "80"),
                                           Freq = nrow(indi_papi_diary) * c(0.121456, 0.122799, 0.060377, 0.054902, 0.028408, 
                                                                             0.077461, 0.041344, 0.052328, 0.048833, 0.048369, 
                                                                             0.11169 , 0.060394, 0.055884, 0.115754))

child_papi_diary_region.dist <- data.frame(region = c("10", "20", "31", "32", "41",
                                                "42", "51", "52", "53", "63",
                                                "64", "71", "72", "80"),
                                     Freq = nrow(child_papi_diary) * c(0.096628, 0.13038 , 0.062331, 0.053434, 0.029065, 
                                                                 0.084549, 0.04399 , 0.053803, 0.051264, 0.050891, 
                                                                 0.107378, 0.061138, 0.056397, 0.118753))



hh_indi_demogr.dist <- data.frame(demogr1 = c("103", "111", "112", "121", "122",
                                              "123", "131", "132", "133", "141",
                                              "142", "143", "200", "211", "221",
                                              "222", "223", "231", "232", "233",
                                              "240", "241", "242", "243"),
                   Freq = nrow(hh_indi) * c(0.000005, 0.086221, 0.000023, 0.012344, 0.059749, 
                                            0.013614, 0.005294, 0.10299 , 0.025546, 0.013345, 
                                            0.131259, 0.025412, 0.000005, 0.080524, 0.011895, 
                                            0.052   , 0.023401, 0.008134, 0.10456 , 0.027987, 
                                            0.000042, 0.056025, 0.140491, 0.019135))

indi_demogr.dist <- data.frame(demogr1 = c("121", "122", "123", "131", "132", 
                                           "133", "141", "142", "143", "221", 
                                           "222", "223", "231", "232", "233", 
                                           "241", "242", "243"),
                     Freq = nrow(indi) * c(0.014816, 0.071712, 0.016339, 0.006355, 0.12361 , 
                                           0.030661, 0.016017, 0.15754 , 0.030499, 0.014277, 
                                           0.062411, 0.028087, 0.009762, 0.125495, 0.033591, 
                                           0.067242, 0.16862 , 0.022966))

indi_proxy_demogr.dist <- data.frame(demogr1 = c("121", "122", "123", "131", "132", 
                                                 "133", "141", "142", "143", "221", 
                                                 "222", "223", "231", "232", "233", 
                                                 "240", "241", "242", "243"),
               Freq = nrow(indi_proxy) * c(0.014815, 0.071709, 0.016339, 0.006354, 0.123604, 
                                           0.030659, 0.016016, 0.157532, 0.030498, 0.014276, 
                                           0.062408, 0.028085, 0.009762, 0.125489, 0.033589, 
                                           0.00005 , 0.067239, 0.168611, 0.022965))

papi_adult_demogr.dist <- data.frame(demogr1 = c("121", "122", "123", "131", "132", 
                                                 "133", "141", "142", "143", "221", 
                                                 "222", "223", "231", "232", "233", 
                                                 "241", "242", "243"),
                    Freq = nrow(papi_adult) * c(0.014816, 0.071712, 0.016339, 0.006355, 0.12361 , 
                                                0.030661, 0.016017, 0.15754 , 0.030499, 0.014277, 
                                                0.062411, 0.028087, 0.009762, 0.125495, 0.033591, 
                                                0.067242, 0.16862 , 0.022966))

papi_child_sex.dist <- data.frame(sex = c("1", "2"),
                                     Freq = nrow(papi_child) * c(0.514028, 0.485972))


adult_child_demogr.dist <- data.frame(demogr2 = c("111", "112", "113", "121", "122", 
                                                  "123", "131", "132", "133", "211", 
                                                  "212", "213", "221", "222", "223", 
                                                  "231", "232", "233"),
                Freq = nrow(adult_child) * c(0.053427, 0.066226, 0.015084, 0.005866, 0.11411 , 
                                             0.028304, 0.014786, 0.145432, 0.028155, 0.050255, 
                                             0.05762 , 0.025928, 0.009012, 0.11585 , 0.031009, 
                                             0.062074, 0.155661, 0.021201))

adult_child15_demogr.dist <- data.frame(demogr3 = c("111", "112", "113", "121", "122", 
                                                    "123", "131", "132", "133", "211", 
                                                    "212", "213", "221", "222", "223", 
                                                    "231", "232", "233"),
             Freq = nrow(adult_child15) * c(0.030234, 0.069582, 0.015848, 0.006163, 0.119892, 
                                            0.029738, 0.015535, 0.1528  , 0.029582, 0.028034, 
                                            0.060539, 0.027242, 0.009469, 0.121719, 0.03258 , 
                                            0.065219, 0.163547, 0.022275))

indi_child15_demogr.dist <- data.frame(demogr3 = c("111", "112", "113", "121", "122", 
                                                   "123", "131", "132", "133", "211", 
                                                   "212", "213", "221", "222", "223", 
                                                   "231", "232", "233"),
              Freq = nrow(indi_child15) * c(0.030234, 0.069582, 0.015848, 0.006163, 0.119892, 
                                            0.029738, 0.015535, 0.1528  , 0.029582, 0.028034, 
                                            0.060539, 0.027242, 0.009469, 0.121719, 0.03258 , 
                                            0.065219, 0.163547, 0.022275))

diary_adult_demogr.dist <- data.frame(demogr1 = c("103", "121", "122", "123", "131", 
                                                  "132", "133", "141", "142", "143", 
                                                  "221", "222", "223", "231", "232", 
                                                  "233", "241", "242", "243"),
               Freq = nrow(papi_adult) * c(0.000006, 0.014816, 0.071712, 0.016339, 0.006354, 
                                           0.123609, 0.030661, 0.016017, 0.157539, 0.030499, 
                                           0.014277, 0.062411, 0.028086, 0.009762, 0.125494, 
                                           0.03359 , 0.067242, 0.168619, 0.022966))

diary_child_sex.dist <- data.frame(sex = c("1", "2"),
                                  Freq = nrow(diary_child) * c(0.514028, 0.485972))

indi_papi_demogr.dist <- data.frame(demogr1 = c("121", "122", "123", "131", "132", 
                                                "133", "141", "142", "143", "221", 
                                                "222", "223", "231", "232", "233", 
                                                "241", "242", "243"),
                  Freq = nrow(indi_papi) * c(0.014816, 0.071712, 0.016339, 0.006355, 0.12361 , 
                                             0.030661, 0.016017, 0.15754 , 0.030499, 0.014277, 
                                             0.062411, 0.028087, 0.009762, 0.125495, 0.033591, 
                                             0.067242, 0.16862 , 0.022966))

indi_diary_demogr.dist <- data.frame(demogr1 = c("121", "122", "123", "131", "132", 
                                                 "133", "141", "142", "143", "221", 
                                                 "222", "223", "231", "232", "233", 
                                                 "241", "242", "243"),
                    Freq = nrow(indi_diary) * c(0.014816, 0.071712, 0.016339, 0.006355, 0.12361 , 
                                                0.030661, 0.016017, 0.15754 , 0.030499, 0.014277, 
                                                0.062411, 0.028087, 0.009762, 0.125495, 0.033591, 
                                                0.067242, 0.16862 , 0.022966))

adult_papi_diary_demogr.dist <- data.frame(demogr1 = c("121", "122", "123", "131", "132", 
                                                       "133", "141", "142", "143", "221", 
                                                       "222", "223", "231", "232", "233", 
                                                       "241", "242", "243"),
            Freq = nrow(adult_papi_diary) * c(0.014816, 0.071712, 0.016339, 0.006355, 0.12361 , 
                                              0.030661, 0.016017, 0.15754 , 0.030499, 0.014277, 
                                              0.062411, 0.028087, 0.009762, 0.125495, 0.033591, 
                                              0.067242, 0.16862 , 0.022966))

indi_papi_diary_demogr.dist <- data.frame(demogr1 = c("121", "122", "123", "131", "132", 
                                                      "133", "141", "142", "143", "221", 
                                                      "222", "223", "231", "232", "233", 
                                                      "241", "242", "243"),
             Freq = nrow(indi_papi_diary) * c(0.014816, 0.071712, 0.016339, 0.006355, 0.12361 , 
                                              0.030661, 0.016017, 0.15754 , 0.030499, 0.014277, 
                                              0.062411, 0.028087, 0.009762, 0.125495, 0.033591, 
                                              0.067242, 0.16862 , 0.022966))

child_papi_diary_sex.dist <- data.frame(sex = c("1", "2"),
                                  Freq = nrow(child_papi_diary) * c(0.514028, 0.485972))



diary_adult_day.dist <- data.frame(day = c("1", "2", "3", "4", "5", "6", "7", "98"),
                              Freq = nrow(diary_adult) * c (0.140074, 0.140074, 0.140074, 0.140074, 
                                                            0.140074, 0.140074, 0.140074, 0.019485))

diary_child_day.dist <- data.frame(day = c("1", "2", "3", "4", "5", "6", "7", "98"),
                                    Freq = nrow(diary_child) * c (0.138593, 0.138593, 0.138593, 0.138593, 
                                                                  0.138593, 0.138593, 0.138593, 0.029851))

indi_diary_day.dist <- data.frame(day = c("1", "2", "3", "4", "5", "6", "7", "98"),
                                        Freq = nrow(indi_diary) * c (0.139926, 0.139926, 0.139926, 0.139926, 
                                                                     0.139926, 0.139926, 0.139926, 0.020516))

adult_papi_diary_day.dist <- data.frame(day = c("1", "2", "3", "4", "5", "6", "7", "98"),
                                        Freq = nrow(adult_papi_diary) * c (0.140222, 0.140222, 0.140222, 0.140222, 
                                                                           0.140222, 0.140222, 0.140222, 0.018448))

indi_papi_diary_day.dist <- data.frame(day = c("1", "2", "3", "4", "5", "6", "7", 98),
                                        Freq = nrow(indi_papi_diary) * c (0.140042, 0.140042, 0.140042, 0.140042, 
                                                                          0.140042, 0.140042, 0.140042, 0.019703))

child_papi_diary_day.dist <- data.frame(day = c("1", "2", "3", "4", "5", "6", "7", "98"),
                                        Freq = nrow(child_papi_diary) * c (0.138817, 0.138817, 0.138817, 0.138817, 
                                                                           0.138817, 0.138817, 0.138817, 0.028278))

#use "raking" method to compute the post-stratification weights.
hh_hh.rake <- rake(design = hh_hh.unweighted,
                     sample.margins = list(~region),
                     population.margins = list(hh_hh_region.dist))

hh_indi.rake <- rake(design = hh_indi.unweighted,
                       sample.margins = list(~demogr1, ~region),
                       population.margins = list(hh_indi_demogr.dist, hh_indi_region.dist))

indi.rake <- rake(design = indi.unweighted,
                     sample.margins = list(~demogr1, ~region),
                     population.margins = list(indi_demogr.dist, indi_region.dist))

indi_proxy.rake <- rake(design = indi_proxy.unweighted,
                  sample.margins = list(~demogr1, ~region),
                  population.margins = list(indi_proxy_demogr.dist, indi_proxy_region.dist))

papi_adult.rake <- rake(design = papi_adult.unweighted,
                        sample.margins = list(~demogr1, ~region),
                        population.margins = list(papi_adult_demogr.dist, papi_adult_region.dist))

papi_child.rake <- rake(design = papi_child.unweighted,
                        sample.margins = list(~sex, ~region),
                        population.margins = list(papi_child_sex.dist, papi_child_region.dist))

adult_child.rake <- rake(design = adult_child.unweighted,
                         sample.margins = list(~demogr2, ~region),
                         population.margins = list(adult_child_demogr.dist, adult_child_region.dist))

adult_child15.rake <- rake(design = adult_child15.unweighted,
                           sample.margins = list(~demogr3, ~region),
                           population.margins = list(adult_child15_demogr.dist, adult_child15_region.dist))

indi_child15.rake <- rake(design = indi_child15.unweighted,
                          sample.margins = list(~demogr3, ~region),
                          population.margins = list(indi_child15_demogr.dist, indi_child15_region.dist))

diary_adult.rake <- rake(design = diary_adult.unweighted,
                         sample.margins = list(~demogr1, ~region),
                         population.margins = list(diary_adult_demogr.dist, diary_adult_region.dist))

diary_adult_D.rake <- rake(design = diary_adult_D.unweighted,
                        sample.margins = list(~demogr1, ~region, ~day),
                        population.margins = list(diary_adult_demogr.dist, diary_adult_region.dist, diary_adult_day.dist))

diary_child.rake <- rake(design = diary_child.unweighted,
                         sample.margins = list(~sex, ~region),
                         population.margins = list(diary_child_sex.dist, diary_child_region.dist))

diary_child_D.rake <- rake(design = diary_child_D.unweighted,
                         sample.margins = list(~sex, ~region, ~day),
                         population.margins = list(diary_child_sex.dist, diary_child_region.dist, diary_child_day.dist))

indi_papi.rake <- rake(design = indi_papi.unweighted,
                         sample.margins = list(~demogr1, ~region),
                         population.margins = list(indi_papi_demogr.dist, indi_papi_region.dist))

indi_diary.rake <- rake(design = indi_diary.unweighted,
                        sample.margins = list(~demogr1, ~region),
                        population.margins = list(indi_diary_demogr.dist, indi_diary_region.dist))

indi_diary_D.rake <- rake(design = indi_diary_D.unweighted,
                       sample.margins = list(~demogr1, ~region, ~day),
                       population.margins = list(indi_diary_demogr.dist, indi_diary_region.dist, indi_diary_day.dist))

adult_papi_diary.rake <- rake(design = adult_papi_diary.unweighted,
                              sample.margins = list(~demogr1, ~region),
                              population.margins = list(adult_papi_diary_demogr.dist, adult_papi_diary_region.dist))

adult_papi_diary_D.rake <- rake(design = adult_papi_diary_D.unweighted,
                        sample.margins = list(~demogr1, ~region, ~day),
                        population.margins = list(adult_papi_diary_demogr.dist, adult_papi_diary_region.dist, adult_papi_diary_day.dist))

indi_papi_diary.rake <- rake(design = indi_papi_diary.unweighted,
                             sample.margins = list(~demogr1, ~region),
                             population.margins = list(indi_papi_diary_demogr.dist, indi_papi_diary_region.dist))

indi_papi_diary_D.rake <- rake(design = indi_papi_diary_D.unweighted,
                              sample.margins = list(~demogr1, ~region, ~day),
                              population.margins = list(indi_papi_diary_demogr.dist, indi_papi_diary_region.dist, indi_papi_diary_day.dist))

child_papi_diary.rake <- rake(design = child_papi_diary.unweighted,
                              sample.margins = list(~sex, ~region),
                              population.margins = list(child_papi_diary_sex.dist, child_papi_diary_region.dist))

child_papi_diary_D.rake <- rake(design = child_papi_diary_D.unweighted,
                         sample.margins = list(~sex, ~region, ~day),
                         population.margins = list(child_papi_diary_sex.dist, child_papi_diary_region.dist, child_papi_diary_day.dist))

summary(weights(hh_hh.rake))
summary(weights(hh_indi.rake))
summary(weights(indi.rake))
summary(weights(indi_proxy.rake))
summary(weights(papi_adult.rake))
summary(weights(papi_child.rake))
summary(weights(adult_child.rake))
summary(weights(adult_child15.rake))
summary(weights(indi_child15.rake))
summary(weights(diary_adult.rake))
summary(weights(diary_adult_D.rake))
summary(weights(diary_child.rake))
summary(weights(diary_child_D.rake))
summary(weights(indi_papi.rake))
summary(weights(indi_diary.rake))
summary(weights(indi_diary_D.rake))
summary(weights(adult_papi_diary.rake))
summary(weights(adult_papi_diary_D.rake))
summary(weights(indi_papi_diary.rake))
summary(weights(indi_papi_diary_D.rake))
summary(weights(child_papi_diary.rake))
summary(weights(child_papi_diary_D.rake))

#truncate weights >= 4.
diary_adult_D.rake.trim <- trimWeights(diary_adult_D.rake, upper=4, strict=TRUE)
indi_diary_D.rake.trim <- trimWeights(indi_diary_D.rake, upper=4, strict=TRUE)
adult_papi_diary_D.rake.trim <- trimWeights(adult_papi_diary_D.rake, upper=4, strict=TRUE)
indi_papi_diary_D.rake.trim <- trimWeights(indi_papi_diary_D.rake, upper=4, strict=TRUE)

summary(weights(diary_adult_D.rake.trim))
summary(weights(indi_diary_D.rake.trim))
summary(weights(adult_papi_diary_D.rake.trim))
summary(weights(indi_papi_diary_D.rake.trim))

#store weights.
W_hh_hh<-weights(hh_hh.rake)
W_hh_indi<-weights(hh_indi.rake)
W_indi<-weights(indi.rake)
W_indi_proxy<-weights(indi_proxy.rake)
W_papi_adult<-weights(papi_adult.rake)
W_papi_child<-weights(papi_child.rake)
W_adult_child<-weights(adult_child.rake)
W_adult_child15<-weights(adult_child15.rake)
W_indi_child15<-weights(indi_child15.rake)
W_diary_adult<-weights(diary_adult.rake)
Wd_diary_adult<-weights(diary_adult_D.rake.trim)
W_diary_child<-weights(diary_child.rake)
Wd_diary_child<-weights(diary_child_D.rake)
W_indi_papi<-weights(indi_papi.rake)
W_indi_diary<-weights(indi_diary.rake)
Wd_indi_diary<-weights(indi_diary_D.rake.trim)
W_adult_papi_diary<-weights(adult_papi_diary.rake)
Wd_adult_papi_diary<-weights(adult_papi_diary_D.rake.trim)
W_indi_papi_diary<-weights(indi_papi_diary.rake)
Wd_indi_papi_diary<-weights(indi_papi_diary_D.rake.trim)
W_child_papi_diary<-weights(child_papi_diary.rake)
Wd_child_papi_diary<-weights(child_papi_diary_D.rake)

#add weights to subsets of data.
hh_hh<-cbind(hh_hh, W_hh_hh)
hh_indi<-cbind(hh_indi, W_hh_indi)
indi<-cbind(indi, W_indi)
indi_proxy<-cbind(indi_proxy, W_indi_proxy)
papi_adult<-cbind(papi_adult, W_papi_adult)
papi_child<-cbind(papi_child, W_papi_child)
adult_child<-cbind(adult_child, W_adult_child)
adult_child15<-cbind(adult_child15, W_adult_child15)
indi_child15<-cbind(indi_child15, W_indi_child15)
diary_adult<-cbind(diary_adult, W_diary_adult)
diary_adult_D<-cbind(diary_adult_D, Wd_diary_adult)
diary_child<-cbind(diary_child, W_diary_child)
diary_child_D<-cbind(diary_child_D, Wd_diary_child)
indi_papi<-cbind(indi_papi, W_indi_papi)
indi_diary<-cbind(indi_diary, W_indi_diary)
indi_diary_D<-cbind(indi_diary_D, Wd_indi_diary)
adult_papi_diary<-cbind(adult_papi_diary, W_adult_papi_diary)
adult_papi_diary_D<-cbind(adult_papi_diary_D, Wd_adult_papi_diary)
indi_papi_diary<-cbind(indi_papi_diary, W_indi_papi_diary)
indi_papi_diary_D<-cbind(indi_papi_diary_D, Wd_indi_papi_diary)
child_papi_diary<-cbind(child_papi_diary, W_child_papi_diary)
child_papi_diary_D<-cbind(child_papi_diary_D, Wd_child_papi_diary)

#combine weights and the original dataset.
hh_hh_keep <- c("pid", "W_hh_hh")
hh_indi_keep <- c("pid", "W_hh_indi")
indi_keep <- c("pid", "W_indi")
indi_proxy_keep <- c("pid", "W_indi_proxy")
papi_adult_keep <- c("pid", "W_papi_adult")
papi_child_keep <- c("pid", "W_papi_child")
adult_child_keep <- c("pid", "W_adult_child")
adult_child15_keep <- c("pid", "W_adult_child15")
indi_child15_keep <- c("pid", "W_indi_child15")
diary_adult_keep <- c("pid", "W_diary_adult")
diary_adult_D_keep <- c("pid", "Wd_diary_adult")
diary_child_keep <- c("pid", "W_diary_child")
diary_child_D_keep <- c("pid", "Wd_diary_child")
indi_papi_keep <- c("pid", "W_indi_papi")
indi_diary_keep <- c("pid", "W_indi_diary")
indi_diary_D_keep <- c("pid", "Wd_indi_diary")
adult_papi_diary_keep <- c("pid", "W_adult_papi_diary")
adult_papi_diary_D_keep <- c("pid", "Wd_adult_papi_diary")
indi_papi_diary_keep <- c("pid", "W_indi_papi_diary")
indi_papi_diary_D_keep <- c("pid", "Wd_indi_papi_diary")
child_papi_diary_keep <- c("pid", "W_child_papi_diary")
child_papi_diary_D_keep <- c("pid", "Wd_child_papi_diary")

hh_hh <- hh_hh[hh_hh_keep]
hh_indi <- hh_indi[hh_indi_keep]
indi <- indi[indi_keep]
indi_proxy <- indi_proxy[indi_proxy_keep]
papi_adult <- papi_adult[papi_adult_keep]
papi_child <- papi_child[papi_child_keep]
adult_child <- adult_child[adult_child_keep]
adult_child15 <- adult_child15[adult_child15_keep]
indi_child15 <- indi_child15[indi_child15_keep]
diary_adult <- diary_adult[diary_adult_keep]
diary_adult_D <- diary_adult_D[diary_adult_D_keep]
diary_child <- diary_child[diary_child_keep]
diary_child_D <- diary_child_D[diary_child_D_keep]
indi_papi <- indi_papi[indi_papi_keep]
indi_diary <- indi_diary[indi_diary_keep]
indi_diary_D <- indi_diary_D[indi_diary_D_keep]
adult_papi_diary <- adult_papi_diary[adult_papi_diary_keep]
adult_papi_diary_D <- adult_papi_diary_D[adult_papi_diary_D_keep]
indi_papi_diary <- indi_papi_diary[indi_papi_diary_keep]
indi_papi_diary_D <- indi_papi_diary_D[indi_papi_diary_D_keep]
child_papi_diary <- child_papi_diary[child_papi_diary_keep]
child_papi_diary_D <- child_papi_diary_D[child_papi_diary_D_keep]

chps_weights <- merge(chps_pid, hh_hh, by="pid", all=TRUE)
chps_weights <- merge(chps_weights, hh_indi, by="pid", all=TRUE)
chps_weights <- merge(chps_weights, indi, by="pid", all=TRUE)
chps_weights <- merge(chps_weights,indi_proxy,by="pid", all=TRUE)
chps_weights <- merge(chps_weights,papi_adult,by="pid", all=TRUE)
chps_weights <- merge(chps_weights,papi_child,by="pid", all=TRUE)
chps_weights <- merge(chps_weights,adult_child,by="pid", all=TRUE)
chps_weights <- merge(chps_weights,adult_child15,by="pid", all=TRUE)
chps_weights <- merge(chps_weights,indi_child15,by="pid", all=TRUE)
chps_weights <- merge(chps_weights,diary_adult,by="pid", all=TRUE)
chps_weights <- merge(chps_weights,diary_adult_D,by="pid", all=TRUE)
chps_weights <- merge(chps_weights,diary_child,by="pid", all=TRUE)
chps_weights <- merge(chps_weights,diary_child_D,by="pid", all=TRUE)
chps_weights <- merge(chps_weights,indi_papi,by="pid", all=TRUE)
chps_weights <- merge(chps_weights,indi_diary,by="pid", all=TRUE)
chps_weights <- merge(chps_weights,indi_diary_D,by="pid", all=TRUE)
chps_weights <- merge(chps_weights,adult_papi_diary,by="pid", all=TRUE)
chps_weights <- merge(chps_weights,adult_papi_diary_D,by="pid", all=TRUE)
chps_weights <- merge(chps_weights,indi_papi_diary,by="pid", all=TRUE)
chps_weights <- merge(chps_weights,indi_papi_diary_D,by="pid", all=TRUE)
chps_weights <- merge(chps_weights,child_papi_diary,by="pid", all=TRUE)
chps_weights <- merge(chps_weights,child_papi_diary_D,by="pid", all=TRUE)

#sava data with weights.
library(foreign)
write.foreign(chps_weights, "chps_w1_weights.txt", 
              "chps_w1_weights.sps",   package="SPSS")